EXPORTS
	??1CWsContainGraphicBitmap@@UAE@XZ @ 1 NONAME ; CWsContainGraphicBitmap::~CWsContainGraphicBitmap(void)
	??1CWsSimpleGraphicBitmap@@UAE@XZ @ 2 NONAME ; CWsSimpleGraphicBitmap::~CWsSimpleGraphicBitmap(void)
	?HandleMessage@CWsContainGraphicBitmap@@UAEXABVTDesC8@@@Z @ 3 NONAME ; void CWsContainGraphicBitmap::HandleMessage(class TDesC8 const &)
	?HandleMessage@CWsSimpleGraphicBitmap@@UAEXABVTDesC8@@@Z @ 4 NONAME ; void CWsSimpleGraphicBitmap::HandleMessage(class TDesC8 const &)
	?NewL@CWsContainGraphicBitmap@@SAPAV1@ABVTWsGraphicId@@@Z @ 5 NONAME ; class CWsContainGraphicBitmap * CWsContainGraphicBitmap::NewL(class TWsGraphicId const &)
	?NewL@CWsContainGraphicBitmap@@SAPAV1@VTUid@@@Z @ 6 NONAME ; class CWsContainGraphicBitmap * CWsContainGraphicBitmap::NewL(class TUid)
	?NewL@CWsContainGraphicBitmap@@SAPAV1@XZ @ 7 NONAME ; class CWsContainGraphicBitmap * CWsContainGraphicBitmap::NewL(void)
	?NewL@CWsInvisibleGraphicBitmap1@@SAPAV1@ABVTWsGraphicId@@@Z @ 8 NONAME ; class CWsInvisibleGraphicBitmap1 * CWsInvisibleGraphicBitmap1::NewL(class TWsGraphicId const &)
	?NewL@CWsInvisibleGraphicBitmap1@@SAPAV1@VTUid@@@Z @ 9 NONAME ; class CWsInvisibleGraphicBitmap1 * CWsInvisibleGraphicBitmap1::NewL(class TUid)
	?NewL@CWsInvisibleGraphicBitmap1@@SAPAV1@XZ @ 10 NONAME ; class CWsInvisibleGraphicBitmap1 * CWsInvisibleGraphicBitmap1::NewL(void)
	?NewL@CWsInvisibleGraphicBitmap2@@SAPAV1@ABVTWsGraphicId@@@Z @ 11 NONAME ; class CWsInvisibleGraphicBitmap2 * CWsInvisibleGraphicBitmap2::NewL(class TWsGraphicId const &)
	?NewL@CWsInvisibleGraphicBitmap2@@SAPAV1@VTUid@@@Z @ 12 NONAME ; class CWsInvisibleGraphicBitmap2 * CWsInvisibleGraphicBitmap2::NewL(class TUid)
	?NewL@CWsInvisibleGraphicBitmap2@@SAPAV1@XZ @ 13 NONAME ; class CWsInvisibleGraphicBitmap2 * CWsInvisibleGraphicBitmap2::NewL(void)
	?NewL@CWsSimpleGraphicBitmap@@SAPAV1@ABVTWsGraphicId@@@Z @ 14 NONAME ; class CWsSimpleGraphicBitmap * CWsSimpleGraphicBitmap::NewL(class TWsGraphicId const &)
	?NewL@CWsSimpleGraphicBitmap@@SAPAV1@VTUid@@@Z @ 15 NONAME ; class CWsSimpleGraphicBitmap * CWsSimpleGraphicBitmap::NewL(class TUid)
	?NewL@CWsSimpleGraphicBitmap@@SAPAV1@XZ @ 16 NONAME ; class CWsSimpleGraphicBitmap * CWsSimpleGraphicBitmap::NewL(void)
	?OnReplace@CWsContainGraphicBitmap@@UAEXXZ @ 17 NONAME ; void CWsContainGraphicBitmap::OnReplace(void)
	?OnReplace@CWsSimpleGraphicBitmap@@UAEXXZ @ 18 NONAME ; void CWsSimpleGraphicBitmap::OnReplace(void)
	?Share@CWsContainGraphicBitmap@@UAEHVTSecureId@@@Z @ 19 NONAME ; int CWsContainGraphicBitmap::Share(class TSecureId)
	?Share@CWsSimpleGraphicBitmap@@UAEHVTSecureId@@@Z @ 20 NONAME ; int CWsSimpleGraphicBitmap::Share(class TSecureId)
	?ShareGlobally@CWsContainGraphicBitmap@@UAEHXZ @ 21 NONAME ; int CWsContainGraphicBitmap::ShareGlobally(void)
	?ShareGlobally@CWsSimpleGraphicBitmap@@UAEHXZ @ 22 NONAME ; int CWsSimpleGraphicBitmap::ShareGlobally(void)
	?UnShare@CWsContainGraphicBitmap@@UAEHVTSecureId@@@Z @ 23 NONAME ; int CWsContainGraphicBitmap::UnShare(class TSecureId)
	?UnShare@CWsSimpleGraphicBitmap@@UAEHVTSecureId@@@Z @ 24 NONAME ; int CWsSimpleGraphicBitmap::UnShare(class TSecureId)
	?UnShareGlobally@CWsContainGraphicBitmap@@UAEHXZ @ 25 NONAME ; int CWsContainGraphicBitmap::UnShareGlobally(void)
	?UnShareGlobally@CWsSimpleGraphicBitmap@@UAEHXZ @ 26 NONAME ; int CWsSimpleGraphicBitmap::UnShareGlobally(void)
	?UpdateColor@CWsContainGraphicBitmap@@QAEHVTRgb@@@Z @ 27 NONAME ; int CWsContainGraphicBitmap::UpdateColor(class TRgb)
	?UpdateColor@CWsSimpleGraphicBitmap@@QAEHVTRgb@@@Z @ 28 NONAME ; int CWsSimpleGraphicBitmap::UpdateColor(class TRgb)

